@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2010 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,8 +23,6 @@
 
 #include <glib.h>
 
-G_BEGIN_DECLS
-
 #include <gdk/gdk.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gtk/gtk.h>
@@ -35,6 +34,4 @@ G_BEGIN_DECLS
 
 extern GtkWidget *main_win_widget;
 
-G_END_DECLS
-
 #endif //__LIBGCMD_DEPS_H__
