@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2010 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -39,8 +40,9 @@
 #include <gtk/gtk.h>
 #include <gdk/gdkx.h>
 #include <gdk/gdkkeysyms.h>
-#include "eggcellrendererkeys.h"
+
 #include "gnome-cmd-includes.h"
+#include "eggcellrendererkeys.h"
 #include "utils.h"
 
 #define EGG_CELL_RENDERER_TEXT_PATH "egg-cell-renderer-text"
@@ -86,7 +88,7 @@ enum
 static GtkCellRendererTextClass *parent_class = NULL;
 
 
-GType egg_cell_renderer_keys_get_type (void)
+GType egg_cell_renderer_keys_get_type ()
 {
     static GType cell_keys_type = 0;
 
@@ -217,7 +219,7 @@ static void egg_cell_renderer_keys_class_init (EggCellRendererKeysClass *cell_ke
 }
 
 
-GtkCellRenderer *egg_cell_renderer_keys_new (void)
+GtkCellRenderer *egg_cell_renderer_keys_new ()
 {
     return GTK_CELL_RENDERER (g_object_new (EGG_TYPE_CELL_RENDERER_KEYS, NULL));
 }
@@ -239,13 +241,13 @@ gchar *egg_accelerator_get_label (guint accel_key, GdkModifierType accel_mods)
     static const gchar text_mod1[] = "Alt+";
     static const gchar text_mod2[] = "Mod2+";
     static const gchar text_mod3[] = "Mod3+";
-#ifdef HAVE_GTK_2_10
+#if GTK_CHECK_VERSION (2, 10, 0)
     static const gchar text_mod4[] = "Mod4+";
 #else
     static const gchar text_mod4[] = "Super+";
 #endif
     static const gchar text_mod5[] = "Mod5+";
-#ifdef HAVE_GTK_2_10
+#if GTK_CHECK_VERSION (2, 10, 0)
     static const gchar text_meta[] = "Meta+";
     static const gchar text_super[] = "Super+";
     static const gchar text_hyper[] = "Hyper+";
@@ -271,7 +273,7 @@ gchar *egg_accelerator_get_label (guint accel_key, GdkModifierType accel_mods)
         l += sizeof(text_mod4)-1;
     if (accel_mods & GDK_MOD5_MASK)
         l += sizeof(text_mod5)-1;
-#ifdef HAVE_GTK_2_10
+#if GTK_CHECK_VERSION (2, 10, 0)
     if (accel_mods & GDK_META_MASK)
         l += sizeof(text_meta)-1;
     if (accel_mods & GDK_HYPER_MASK)
@@ -318,7 +320,7 @@ gchar *egg_accelerator_get_label (guint accel_key, GdkModifierType accel_mods)
       strcpy (s, text_mod5);
       s +=  sizeof(text_mod5)-1;
     }
-#ifdef HAVE_GTK_2_10
+#if GTK_CHECK_VERSION (2, 10, 0)
     if (accel_mods & GDK_META_MASK)
     {
       strcpy (s, text_meta);
@@ -444,7 +446,7 @@ void egg_cell_renderer_keys_get_size (GtkCellRenderer *cell,
 
 static gboolean grab_key_callback (GtkWidget *widget, GdkEventKey *event, EggCellRendererKeys *keys)
 {
-#ifdef HAVE_GTK_2_10
+#if GTK_CHECK_VERSION (2, 10, 0)
     if (event->is_modifier)
         return TRUE;
 #else
@@ -481,7 +483,7 @@ static gboolean grab_key_callback (GtkWidget *widget, GdkEventKey *event, EggCel
     if (accel_key == GDK_ISO_Left_Tab)
         accel_key = GDK_Tab;
 
-#ifdef HAVE_GTK_2_10
+#if GTK_CHECK_VERSION (2, 10, 0)
     accel_mods = event->state & gtk_accelerator_get_default_mod_mask ();
 #else
     accel_mods = event->state & (GDK_CONTROL_MASK | GDK_SHIFT_MASK | GDK_MOD1_MASK | GDK_MOD4_MASK);
@@ -512,8 +514,9 @@ static gboolean grab_key_callback (GtkWidget *widget, GdkEventKey *event, EggCel
     if (keys->accel_mode == GTK_CELL_RENDERER_ACCEL_MODE_GTK)
         if (accel_key != GDK_Tab && !gtk_accelerator_valid (accel_key, (GdkModifierType) accel_mods))
         {
-            // gtk_widget_error_bell (widget);     // FIXME: since 2.12, uncomment when dependency is met
-
+#if GTK_CHECK_VERSION (2, 12, 0)
+            gtk_widget_error_bell (widget);
+#endif
             return TRUE;
         }
 
@@ -563,7 +566,7 @@ static void pointless_eventbox_cell_editable_init (GtkCellEditableIface *iface)
 }
 
 
-static GType pointless_eventbox_subclass_get_type (void)
+static GType pointless_eventbox_subclass_get_type ()
 {
   static GType eventbox_type = 0;
 
@@ -686,7 +689,7 @@ void egg_cell_renderer_keys_set_accelerator (EggCellRendererKeys *keys, guint ke
     if (changed)
     {
         // sync string to the key values
-        GtkCellRendererText *celltext = GTK_CELL_RENDERER_TEXT (keys);
+        // GtkCellRendererText *celltext = GTK_CELL_RENDERER_TEXT (keys);
         char *text = egg_accelerator_get_label (keys->accel_key, keys->accel_mask);
         g_object_set (keys, "text", text, NULL);
         g_free (text);
