@@ -1,6 +1,7 @@
 /*
   GNOME Commander - A GNOME based file manager
   Copyright (C) 2001-2006 Marcus Bjurman
+  Copyright (C) 2007-2010 Piotr Eljasiak
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -22,9 +23,12 @@
 
 #include "gnome-cmd-file.h"
 
-void gnome_cmd_advrename_reset_counter(unsigned start=1, unsigned precision=-1, unsigned step=1);
-void gnome_cmd_advrename_parse_fname(const char *fname);
-char *gnome_cmd_advrename_gen_fname(char *new_fname, size_t new_fname_size, GnomeCmdFile *finfo);
+#ifndef NAME_MAX
+#define NAME_MAX (FILENAME_MAX)
+#endif
 
+void gnome_cmd_advrename_reset_counter(long start=1, int precision=-1, int step=1);
+void gnome_cmd_advrename_parse_template(const char *template_string, gboolean &has_counters);
+char *gnome_cmd_advrename_gen_fname(GnomeCmdFile *f, size_t new_fname_size=NAME_MAX);
 
 #endif // __GNOME_CMD_ADVRENAME_LEXER_H__
