@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2010 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,6 +23,7 @@
 #include <sys/wait.h>
 #include <libgnomevfs/gnome-vfs.h>
 #include <libgnomevfs/gnome-vfs-volume.h>
+
 #include "gnome-cmd-includes.h"
 #include "gnome-cmd-data.h"
 #include "gnome-cmd-con-device.h"
@@ -34,7 +36,7 @@
 using namespace std;
 
 
-struct _GnomeCmdConDevicePrivate
+struct GnomeCmdConDevicePrivate
 {
     gchar *alias;
     gchar *device_fn;
@@ -193,9 +195,9 @@ static void dev_vfs_umount_callback (gboolean succeeded, char *error, char *deta
 {
     GtkWidget *msgbox;
 
-    DEBUG('m',"VFS Umount Callback: %s %s %s\n", succeeded ? "Succeeded" : "Failed",
-              error ? error : "",
-              detailed_error ? detailed_error : "");
+    DEBUG('m', "VFS Umount Callback: %s %s %s\n", succeeded ? "Succeeded" : "Failed",
+               error ? error : "",
+               detailed_error ? detailed_error : "");
 
     if (succeeded)
     {
@@ -242,7 +244,7 @@ static gboolean dev_close (GnomeCmdCon *con)
             DEBUG ('m', "umounting VFS volume \"%s\"\n", name);
             g_free (name);
 
-            gnome_vfs_volume_unmount(dev_con->priv->vfsvol,dev_vfs_umount_callback,NULL);
+            gnome_vfs_volume_unmount(dev_con->priv->vfsvol, dev_vfs_umount_callback, NULL);
         }
     }
     else
@@ -365,7 +367,7 @@ static void init (GnomeCmdConDevice *dev_con)
  * Public functions
  ***********************************/
 
-GtkType gnome_cmd_con_device_get_type (void)
+GtkType gnome_cmd_con_device_get_type ()
 {
     static GtkType type = 0;
 
@@ -416,7 +418,7 @@ void gnome_cmd_con_device_set_alias (GnomeCmdConDevice *dev, const gchar *alias)
 
     dev->priv->alias = g_strdup (alias);
     GNOME_CMD_CON (dev)->alias = g_strdup (alias);
-    GNOME_CMD_CON (dev)->go_text = g_strdup_printf (_("Go to: %s (%s)"), alias,dev->priv->mountp);
+    GNOME_CMD_CON (dev)->go_text = g_strdup_printf (_("Go to: %s (%s)"), alias, dev->priv->mountp);
     GNOME_CMD_CON (dev)->open_text = g_strdup_printf (_("Mount: %s"), alias);
     GNOME_CMD_CON (dev)->close_text = g_strdup_printf (_("Unmount: %s"), alias);
 }
@@ -470,7 +472,7 @@ void gnome_cmd_con_device_set_icon_path (GnomeCmdConDevice *dev, const gchar *ic
 
     if (icon_path)
     {
-        guint dev_icon_size = gnome_cmd_data_get_dev_icon_size ();
+        guint dev_icon_size = gnome_cmd_data.dev_icon_size;
 
         con->go_pixmap = gnome_cmd_pixmap_new_from_file (icon_path, dev_icon_size, dev_icon_size);
         con->open_pixmap = gnome_cmd_pixmap_new_from_file (icon_path, dev_icon_size, dev_icon_size);
