@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2010 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,7 +23,6 @@
 
 #include "gnome-cmd-file.h"
 
-GtkWidget*
-gnome_cmd_file_props_dialog_create (GnomeCmdFile *finfo);
+GtkWidget *gnome_cmd_file_props_dialog_create (GnomeCmdFile *f);
 
 #endif // __GNOME_CMD_FILE_PROPS_DIALOG_H__
