@@ -1,7 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
-    Copyright (C) 2007-2009 Piotr Eljasiak
+    Copyright (C) 2007-2010 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -292,8 +292,7 @@ static void search_dir_r (GnomeCmdDir *dir, SearchData *data)
         if (GNOME_CMD_IS_DIR (f) && data->recurse)
         {
             // we don't want to go backwards or follow symlinks
-            if (strcmp (f->info->name, ".") != 0 &&
-                strcmp (f->info->name, "..") != 0 &&
+            if (!f->is_dotdot && strcmp (f->info->name, ".") != 0 &&
                 !GNOME_VFS_FILE_INFO_SYMLINK (f->info))
             {
                 GnomeCmdDir *new_dir = GNOME_CMD_DIR (f);
