@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2010 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,6 +20,7 @@
 
 #include <config.h>
 #include <unistd.h>
+
 #include "gnome-cmd-includes.h"
 #include "gnome-cmd-xfer.h"
 #include "gnome-cmd-file-selector.h"
@@ -259,7 +261,7 @@ static gboolean update_xfer_gui_func (XferData *data)
 
     if (data->done)
     {
-        // Remove files from the source file-list when a move operation has finished
+        // Remove files from the source file list when a move operation has finished
         if (data->xferOptions & GNOME_VFS_XFER_REMOVESOURCE)
             if (data->src_fl && data->src_files)
             {
@@ -268,9 +270,9 @@ static gboolean update_xfer_gui_func (XferData *data)
                     previous function used here:
                     gnome_cmd_file_list_remove_files (data->src_fl, data->src_files);
 
-                    After 'async_xfer_callback' has been called the file-list, 'src_files' has
+                    After 'async_xfer_callback' has been called the file list, 'src_files' has
                     not been altered and source files that have moved might be write protected.
-                    So we need to check if files that are to be removed from the file-list
+                    So we need to check if files that are to be removed from the file list
                     still exist.
 
                 *************************************************************************/
@@ -279,7 +281,7 @@ static gboolean update_xfer_gui_func (XferData *data)
                 {
                     GnomeVFSURI *src_uri = gnome_cmd_file_get_uri ((GnomeCmdFile *) data->src_files->data);
                     if (!gnome_vfs_uri_exists (src_uri))
-                        gnome_cmd_file_list_remove_file (data->src_fl, (GnomeCmdFile *) data->src_files->data);
+                        data->src_fl->remove_file((GnomeCmdFile *) data->src_files->data);
                     g_free (src_uri);
                 }
             }
@@ -426,19 +428,19 @@ gnome_cmd_xfer_uris_start (GList *src_uri_list,
     gtk_widget_show (GTK_WIDGET (data->win));
 
     //  start the transfer
-    GnomeVFSResult result = gnome_vfs_async_xfer (&data->handle,
-                                                  data->src_uri_list,
-                                                  data->dest_uri_list,
-                                                  xferOptions,
-                                                  GNOME_VFS_XFER_ERROR_MODE_QUERY,
-                                                  xferOverwriteMode,
-                                                  XFER_PRIORITY,
-                                                  (GnomeVFSAsyncXferProgressCallback) async_xfer_callback,
-                                                  data,
-                                                  xfer_callback,
-                                                  data);
+    gnome_vfs_async_xfer (&data->handle,
+                          data->src_uri_list,
+                          data->dest_uri_list,
+                          xferOptions,
+                          GNOME_VFS_XFER_ERROR_MODE_QUERY,
+                          xferOverwriteMode,
+                          XFER_PRIORITY,
+                          (GnomeVFSAsyncXferProgressCallback) async_xfer_callback,
+                          data,
+                          xfer_callback,
+                          data);
 
-    g_timeout_add (gnome_cmd_data_get_gui_update_rate (), (GSourceFunc) update_xfer_gui_func, data);
+    g_timeout_add (gnome_cmd_data.gui_update_rate, (GSourceFunc) update_xfer_gui_func, data);
 }
 
 
@@ -524,5 +526,5 @@ gnome_cmd_xfer_tmp_download_multiple (GList *src_uri_list,
                                    xfer_callback,
                                    data);
 
-    g_timeout_add (gnome_cmd_data_get_gui_update_rate (), (GSourceFunc) update_xfer_gui_func, data);
+    g_timeout_add (gnome_cmd_data.gui_update_rate, (GSourceFunc) update_xfer_gui_func, data);
 }
