@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2010 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,8 +24,6 @@
 #include "libgcmd/libgcmd-deps.h"
 #include "gnome-cmd-combo.h"
 
-G_BEGIN_DECLS
-
 inline GtkWidget *create_clist_combo (GtkWidget *parent, gint num_cols, gint text_col, gchar **titles)
 {
     GtkWidget *combo = gnome_cmd_combo_new (num_cols, text_col, titles);
@@ -35,6 +34,4 @@ inline GtkWidget *create_clist_combo (GtkWidget *parent, gint num_cols, gint tex
     return combo;
 }
 
-G_END_DECLS
-
 #endif // __WIDGET_FACTORY_H__
